# What is this plugin for?

This is not managing Github cloud resources today. It exists to comply with plugin interface. Github Plugin today provides GithubApp integrations for iambic templates.

# Compatible versions of Github

* GitHub Free
* GitHub Team
* Github Enterprise Cloud
